| alimentation | R Documentation |
The 'alimentation' data set contains the percentage composition of food consumption in 25 European countries during the 1980s. The food categories are:
'RM': red meat (pork, veal, beef),
'WM': white meat (chicken),
'E': eggs,
'M': milk,
'F': fish,
'C': cereals,
'S': starch (potatoes),
'N': nuts,
'FV': fruits and vegetables.
The data set also contains categorical variables indicating whether the country belongs to the North or South/Mediterranean group, and whether it is an Eastern or Western European country.
alimentation
An object of class data.frame with 25 rows and 13 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.