| blood_mn | R Documentation |
In humans, the main blood group systems are the ABO system, the Rh system, and the MN system. The MN blood system is related to proteins of the red blood cell plasma membrane. Its inheritance pattern is autosomal with codominance, meaning that the heterozygous phenotype is distinct from both homozygous phenotypes.
The three phenotypes are M, N, and MN. Their frequencies vary across populations. Under the Hardy-Weinberg principle, allele and genotype frequencies remain constant across generations in the absence of evolutionary forces, implying that
\frac{x_{MM} x_{NN}}{x_{MN}^2} = \frac{1}{4}
where x_{MM} and x_{NN} are the genotype frequencies of the
homozygotes and x_{MN} is the genotype frequency of heterozygotes.
blood_mn
An object of class data.frame with 49 rows and 5 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.