| cc_basis | R Documentation |
Construct an ilr basis rotated according to canonical correlations between a compositional response data set and an explanatory data set.
cc_basis(Y, X)
Y |
A compositional data set. |
X |
An explanatory data set. |
A matrix whose columns define a canonical-correlation-oriented ilr basis.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.