| cdp_basis | R Documentation |
Construct the default isometric log-ratio basis used in CoDaPack.
cdp_basis(dim)
dim |
Number of parts. It can be a single integer, a matrix or data frame, or a character vector of part names. |
A matrix with D rows and D - 1 columns containing the
CoDaPack default ilr basis.
cdp_basis(5)
cdp_basis(c("a", "b", "c", "d"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.