| house_expend | R Documentation |
The 'house_expend' data set, obtained from Eurostat, records the composition of mean household consumption expenditure across 12 expenditure categories in 27 European Union countries. Some values are rounded zeros.
In addition, the data set contains gross domestic product values for 2005 ('GDP05') and 2014 ('GDP14'). A relevant analysis is the relationship between expenditure compositions and GDP.
house_expend
An object of class data.frame with 27 rows and 15 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.