| montana | R Documentation |
The 'montana' data set contains 229 samples of the concentration (in ppm) of
five minor elements [Cr, Cu, Hg, U, V] in coal ashes from the Fort
Union formation (Montana, USA), in the Powder River Basin.
The five measured elements form a fully observed subcomposition of a much
larger chemical composition. Since the data are given in parts per million and
all concentrations were measured, a residual component could in principle be
added to close the compositions to 10^6.
montana
An object of class data.frame with 229 rows and 6 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.