| pairwise_basis | R Documentation |
Construct the system of all pairwise log-ratios between parts.
pairwise_basis(dim)
dim |
Number of parts. It can be a single integer, a matrix or data frame, or a character vector of part names. |
A matrix, or a sparse matrix for large dimensions, whose columns represent all pairwise log-ratio generators.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.