View source: R/pb_basis_constrained.R
| pb_subcomposition | R Documentation |
Recursively construct balances on selected subcompositions, optionally enforcing groups of variables to remain together through constraints.
pb_subcomposition(
X,
variables = seq_len(ncol(X)),
constraints = NULL,
angle = FALSE
)
X |
Compositional data set. |
variables |
Indices of the variables currently considered. |
constraints |
Optional list of groups of variables to be constrained together during the recursive search. |
angle |
Logical; if 'TRUE', use the angle criterion instead of the variance criterion when computing constrained balances. |
A list of balance vectors.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.