| serprot | R Documentation |
The 'serprot' data set records the percentages of four serum proteins from blood samples of 30 patients. Fourteen patients have one disease and sixteen have another.
The four-part compositions are formed by
[albumin, pre\text{-}albumin, globulin\ A, globulin\ B].
serprot
An object of class data.frame with 36 rows and 7 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.