| alr_basis | R Documentation |
Construct the transformation matrix associated with additive log-ratio (alr) coordinates.
alr_basis(dim, denominator = NULL, numerator = NULL)
dim |
Number of parts. It can be a single integer, a matrix or data frame, or a character vector of part names. |
denominator |
Part used as denominator. By default, the last part is used. |
numerator |
Parts used as numerators. By default, all parts except the denominator are used, preserving their original order. |
A matrix defining the alr coordinate system.
Aitchison, J. (1986). The Statistical Analysis of Compositional Data. Chapman & Hall, London.
alr_basis(5)
alr_basis(5, 3)
alr_basis(5, 3, c(1, 5, 2, 4))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.