| composition | R Documentation |
Reconstruct a composition from coordinates with respect to a given basis.
composition(H, basis = "ilr")
comp(H, basis = "ilr")
H |
Coordinates of a composition. It can be a numeric matrix, a data frame, or a numeric vector. |
basis |
Basis used to interpret the coordinates. Either a character string naming a predefined basis or a matrix. |
A composition corresponding to the given coordinates.
coordinates, ilr_basis, alr_basis,
clr_basis, sbp_basis
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.