Learn R Programming

coda.base (version 0.4.1)

composition: Get composition from coordinates w.r.t. an specific basis

Description

Calculate a composition from coordinates with respect a given basis

Usage

composition(H, basis = NULL, label = "x", sparse_basis = FALSE)

comp(H, basis = NULL, label = "x", sparse_basis = FALSE)

Value

coordinates with respect the given basis

Arguments

H

coordinates of a composition. Either a matrix, a data.frame or a vector

basis

basis used to calculate the coordinates

label

name given to the coordinates

sparse_basis

Is the given matrix basis sparse? If TRUE calculation are carried taking into an account sparsity (default `FALSE`)

See Also

See functions ilr_basis, alr_basis, clr_basis, sbp_basis to define different compositional basis. See function coordinates to obtain details on how to calculate coordinates of a given composition.