Calculate a composition from coordinates with respect a given basis
composition(H, basis = NULL, label = "x", sparse_basis = FALSE)comp(H, basis = NULL, label = "x", sparse_basis = FALSE)
coordinates with respect the given basis
coordinates of a composition. Either a matrix, a data.frame or a vector
basis used to calculate the coordinates
name given to the coordinates
Is the given matrix basis sparse? If TRUE calculation are carried taking into an account sparsity (default `FALSE`)
See functions ilr_basis, alr_basis,
clr_basis, sbp_basis
to define different compositional basis.
See function coordinates to obtain details on how to calculate
coordinates of a given composition.