| partial_pb_constrained | R Documentation |
Builds a single grouped constrained principal balance from the first principal component of the grouped composition.
partial_pb_constrained(X, lI = NULL, constrained.criterion = "variance")
X |
A numeric matrix with strictly positive finite entries. Rows are observations and columns are compositional parts. |
lI |
A list defining a partition of a subset of the columns of
|
constrained.criterion |
Criterion used to choose the constrained
balance. Either |
A list with the following elements:
dimDimension of the grouped problem, equal to
length(lI) - 1.
lIThe input grouping structure.
varianceVariance criterion of the selected grouped balance.
balance_rawInteger vector in \{-1,0,1\} describing
the selected grouped split.
balanceThe corresponding one-column balance basis.
constrained.criterionCriterion used to construct the balance.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.