| partial_pb_exact | R Documentation |
Finds the grouped balance with maximum variance among all assignments whose
number of active groups is between min_parts and max_parts.
partial_pb_exact(
X,
lI = NULL,
min_parts = 2,
max_parts = NULL,
method = "restricted"
)
X |
A numeric matrix with strictly positive finite entries. Rows are observations and columns are compositional parts. |
lI |
A list defining a partition of a subset of the columns of
|
min_parts |
Integer. Minimum number of active groups. |
max_parts |
Integer or |
method |
Exhaustive search method. Currently only |
The search enumerates only supports whose size is between
min_parts and max_parts. For each support, signs are generated
in binary Gray-code order, fixing the first active group on the left side to
avoid evaluating both a balance and its sign reversal.
A list with the following elements:
dimDimension of the grouped problem, equal to
length(lI) - 1.
lIThe input grouping structure.
varianceVariance criterion of the best grouped balance.
balance_rawInteger vector in \{-1,0,1\} describing
the best grouped split.
balanceThe corresponding one-column balance basis.
min_partsMinimum number of active groups.
max_partsMaximum number of active groups.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.